# Import a standard function, and get the HTML request and response objects.
#from Products.PythonScripts.standard import html_quote
#request = container.REQUEST
#RESPONSE =  request.RESPONSE

#PATH = string.replace(context.surl, container.REQUEST['BASE0'],'')
PATH = context.getInstancePath()

otwocc = []

occtypes = context.Data.OccurrenceTypes.objectIds()

for x in context.Data.ObjectType.objectIds(): 
    PATHOBJTYPE = PATH + '/Data/ObjectType/' + x
    ObjTypeRef = context.restrictedTraverse(PATHOBJTYPE)
    for y in ObjTypeRef.propertyIds():
        if y in occtypes :
             t = (x,context.getAnyProperty(x,'ObjectType','BaseName'))
             otwocc.append(t) 

for y in range(0,len(otwocc)-1):
    if otwocc[y][0]==otwocc[y+1][0]:
       otwocc.pop(y+1)

return otwocc
